

set -ex



test -f ${PREFIX}/lib/libprotoc.a
test -f ${PREFIX}/lib/libprotobuf.a
test -f ${PREFIX}/lib/libprotobuf-lite.a
cd cmake_test
cmake -GNinja $CMAKE_ARGS -DCMAKE_BUILD_TYPE=Release .
cmake --build . --config Release
exit 0
